#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/install.sh - installation file for mini_httpd module
#
# Copyright (c) 2004-2010 Marcus Herleb, herleb(at)herleb(dot)de
# Copyright (c) 2011-2012 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2004-01-01 mh
# Last Update:  $Id: install.sh 30639 2012-04-29 09:55:23Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# include eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib
. /var/install/include/check-eisfair-version

# set variables
module_name='mini_httpd_unimount'

mini_httpd_path=/usr/local/htdocs

mecho --info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

mecho "adding menu ..."
/var/install/bin/add-menu -menu "setup.services.mini_httpd.module.menu" \
    "setup.services.mini_httpd.module.${module_name}.menu" "Unimount - Universal Mounter"

# menue entry does not exist - create it
mecho "adding ${module_name} module menu ..."

# delete menu entries (if already exist)
for CGINAME in ./unimount/unimount.cgi ./unimount/unimount.html
do
    /usr/local/bin/httpd-menu.sh rem "${CGINAME}"
done

# make menu entry (to update old installations)
if [ -f ${mini_httpd_path}/unimount/unimount.html ]
then
    /usr/local/bin/httpd-menu.sh add "./unimount/unimount.html" "Unimount" "Tools"
fi

# check directories and files
mecho "setting file/directory access rights ..."

chmod -R 550 ${mini_httpd_path}/unimount/*.cgi
chmod -R 550 ${mini_httpd_path}/unimount/*.sh

# rename log file
if [ -f /var/log/log.admin ]
then
    mv /var/log/log.admin /var/log/log.unimount
fi

# install/update package configuration file
update=false
if install_config ${module_name}
then
    update=true
fi

# configuration
mecho "creating ${module_name} configuration ..."

if [ "${update}" = "true" ]
then
    # updated installation
    /var/install/config.d/${module_name}.sh
    if [ -f /etc/init.d/${module_name} ]
    then
        /etc/init.d/${module_name} restart
    fi
else
    # new installation
    /var/install/bin/edit -apply "${module_name}" "Edit ${module_name} services configuration"
fi

exit 0
