#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/bin/mini_httpd_unimount-update.sh - update or generate new configuration
#
# Copyright (c) 2004-2010 Marcus Herleb, herleb(at)herleb(dot)de
# Copyright (c)      2011 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2011-06-09  jed
# Last Update:  $Id: mini_httpd_unimount-update.sh 28530 2011-06-10 15:38:42Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# read eislib
. /var/install/include/eislib
. /var/install/include/configlib

#------------------------------------------------------------------------------
# function: variable is set
#
# input:  $1 - variable name
# return:  0 - variable set
#          1 - variable not set
#------------------------------------------------------------------------------
function variable_set ()
{
    eval _var1=\$"${1}"
    eval _var2=\$"{${1}+EMPTY}"

    if [ -z "${_var1}" ]
    then
        if [ "${_var2}" = "EMPTY" ]
        then
            # variable is empty, but set
            ret=0
        else
            # variable is not set
            ret=1
        fi
    else
        # variable has a value
        ret=0
    fi

    return ${ret}
}

#------------------------------------------------------------------------------
# print variable only if it has been set
# $1 - variable name
# $2 - comment
#------------------------------------------------------------------------------
printsetvar ()
{
    if variable_set "${1}"
    then
        printvar "${1}" "${2}"
    fi
}

#------------------------------------------------------------------------------
# rename variables
#------------------------------------------------------------------------------
rename_variables ()
{
    renamed=0
    mecho "renaming parameter(s) ..."

    # v0.90.10
    if [ ! -z "`grep ^MOUNT_INFO ${source_conf}`" ]
    then
        mecho "- MOUNT_INFO -> UNIMOUNT_INFO"
        UNIMOUNT_INFO="${MOUNT_INFO}"
        renamed=1
    fi

    if [ ! -z "`grep ^MOUNT_USB ${source_conf}`" ]
    then
        mecho "- MOUNT_USB -> UNIMOUNT_USB"
        UNIMOUNT_USB="${MOUNT_USB}"
        renamed=1
    fi

    if [ ! -z "`grep ^MOUNT_N ${source_conf}`" ]
    then
        mecho "- MOUNT_N -> UNIMOUNT_N"
        UNIMOUNT_N="${MOUNT_N}"
        renamed=1

        # old configuration
        if [ ${MOUNT_N} -eq 0 ]
        then
            imax=3
        else
            imax=${MOUNT_N}
        fi
    elif [ ! -z "`grep ^UNIMOUNT_N ${source_conf}`" ]
    then
        # new configuration
        if [ ${UNIMOUNT_N} -eq 0 ]
        then
            imax=3
        else
            imax=${UNIMOUNT_N}
        fi
    fi

    idx=1
    while [ ${idx} -le ${imax} ]
    do
        for PNAME in NAME DEVICE POINT OPTION TYPE
        do
            if [ ! -z "`grep ^MOUNT_${idx}_${PNAME} ${source_conf}`" ]
            then
                eval old_val='$MOUNT_'${idx}'_'${PNAME}
                eval new_val="UNIMOUNT_${idx}_${PNAME}"

                case ${PNAME} in
                    TYPE)
                        if [ "${old_val}" != "" ]
                        then
                            # set only if not empty
                            mecho "- MOUNT_${idx}_${PNAME} -> UNIMOUNT_${idx}_${PNAME}"
                            eval "${new_val}=\"${old_val}\""
                            renamed=1
                        fi
                        ;;
                    *)
                        mecho "- MOUNT_${idx}_${PNAME} -> UNIMOUNT_${idx}_${PNAME}"
                        eval "${new_val}=\"${old_val}\""
                        renamed=1
                        ;;
                esac
            fi
        done

        if [ ! -z "`grep ^MOUNT_${idx}_UID ${source_conf}`" ]
        then
            eval uid_old='$MOUNT_'${idx}'_UID'
            eval uid_new="UNIMOUNT_${idx}_USER"

            if [ "${uid_val}" != "" ]
            then
                # set only if not empty
                mecho "- MOUNT_${idx}_UID -> UNIMOUNT_${idx}_USER"
                eval "${uid_new}=\"${uid_old}\""
                renamed=1
            fi
        fi

        if [ ! -z "`grep ^MOUNT_${idx}_GID ${source_conf}`" ]
        then
            eval gid_old='$MOUNT_'${idx}'_GID'
            eval gid_new="UNIMOUNT_${idx}_GROUP"

            if [ "${gid_val}" != "" ]
            then
                # set only if not empty
                mecho "- MOUNT_${idx}_GID -> UNIMOUNT_${idx}_GROUP"
                eval "${gid_new}=\"${gid_old}\""
                renamed=1
            fi
        fi

        if [ ! -z "`grep ^MOUNT_${idx}_USERNAME ${source_conf}`" ]
        then
            eval name_old='$MOUNT_'${idx}'_USERNAME'
            eval name_new="UNIMOUNT_${idx}_AUTH_USER"

            mecho "- MOUNT_${idx}_USERNAME -> UNIMOUNT_${idx}_AUTH_USER"
            eval "${name_new}=\"${name_old}\""
            renamed=1
        fi

        if [ ! -z "`grep ^MOUNT_${idx}_PASSWORD ${source_conf}`" ]
        then
            eval pass_old='$MOUNT_'${idx}'_PASSWORD'
            eval pass_new="UNIMOUNT_${idx}_AUTH_PASS"

            mecho "- MOUNT_${idx}_PASSWORD -> UNIMOUNT_${idx}_AUTH_PASS"
            eval "${pass_new}=\"${pass_old}\""
            renamed=1
        fi

        idx=`expr ${idx} + 1`
    done

    if [ ${renamed} -eq 1 ]
    then
        mecho -info "... read documentation for renamed parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------------
modify_variables ()
{
    modified=0
    mecho "modifying parameter(s) ..."

  # if [ "$EXISCAN_CRYPT_SALT" = "" ]
  # then
  #     randsalt="`random_char``random_char`"
  #     mecho "-EXISCAN_CRYPT_SALT, '' -> '$randsalt'"
  #     EXISCAN_CRYPT_SALT="$randsalt"
  #     modified=1
  # fi

    if [ ${modified} -eq 1 ]
    then
        mecho -info "... read documentation for modified parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
pre_add_variables ()
{
    added=0
    mecho "pre-adding new parameter(s) ..."

    # v0.90.10
    if [ -z "`grep ^START_UNIMOUNT ${source_conf}`" ]
    then
        mecho "- START_UNIMOUNT='no'"
        START_UNIMOUNT='no'
        added=1
    fi

    if [ ${added} -eq 1 ]
    then
        mecho -info "... read documentation for new parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
add_variables ()
{
    added=0
    mecho "adding new parameter(s) ..."

    # v0.90.10
    if [ "${UNIMOUNT_N}" = "" -o ${UNIMOUNT_N} -eq 0 ]
    then
        imax=1
        def_answer='no'
    else
        imax=${UNIMOUNT_N}
        def_answer='yes'
    fi

    idx=1
    while [ ${idx} -le ${imax} ]
    do
        eval atest='$UNIMOUNT_'${idx}'_ACTIVE'

        if [ "${atest}" = "" -a -z "`grep ^UNIMOUNT_${idx}_ACTIVE ${source_conf}`" ]
        then
            mecho "- UNIMOUNT_${idx}_ACTIVE='${def_answer}'"
            eval "UNIMOUNT_${idx}_ACTIVE='${def_answer}'"
            added=1
        fi

        idx=`expr ${idx} + 1`
    done

    if [ ${added} -eq 1 ]
    then
        mecho -info "... read documentation for new parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# delete variables
#------------------------------------------------------------------------------
delete_variables ()
{
    deleted=0
    mecho "deleting old parameters ..."

  # for varname in "ANTISPAM_LOG_COUNT ANTISPAM_LOG_INTERVAL ANTISPAM_ACTIVATE_OSIRU_RBL"
  # do
  #     if [ ! -z "`grep \"^$varname\" $source_conf`" ]
  #     then
  #         mecho "- $varname"
  #         deleted=1
  #     fi
  # done

    if [ ${deleted} -eq 1 ]
    then
        anykey
    fi
}

#------------------------------------------------------------------------------
# create new configuration
#------------------------------------------------------------------------------
create_config ()
{
    mecho "updating/creating configuration ..."

    {
        #------------------------------------------------------------------------------
        printgpl -conf "${module_name}" "2011-04-18" "jed"
        #------------------------------------------------------------------------------
        #------------------------------------------------------------------------------
        printgroup "general settings"
        #------------------------------------------------------------------------------

        printvar "START_UNIMOUNT"                 "start unimount: yes or no"
        echo
        printvar "UNIMOUNT_INFO"                  "show mount information"
        printvar "UNIMOUNT_USB"                   "allow to mount usb devices"

        #------------------------------------------------------------------------------
        printgroup "mount settings"
        #------------------------------------------------------------------------------

        printvar "UNIMOUNT_N"                       "number of mounts"

        if [ ${UNIMOUNT_N} -eq 0 ]
        then
            imax=1
        else
            imax=${UNIMOUNT_N}
        fi

        idx=1
        while [ ${idx} -le ${imax} ]
        do
            echo
            printvar    "UNIMOUNT_${idx}_ACTIVE"    "${idx}. activate mount: yes, no"
            printvar    "UNIMOUNT_${idx}_NAME"      "   name of mount"
            printvar    "UNIMOUNT_${idx}_DEVICE"    "   name of device"
            printvar    "UNIMOUNT_${idx}_POINT"     "   mountpoint"
            printvar    "UNIMOUNT_${idx}_OPTION"    "   mount options"
            printsetvar "UNIMOUNT_${idx}_USER"      "   user to be used instead of 'root'"
            printsetvar "UNIMOUNT_${idx}_GROUP"     "   group to be used instead of 'root'"
            printsetvar "UNIMOUNT_${idx}_TYPE"      "   file system type"
            printsetvar "UNIMOUNT_${idx}_AUTH_USER" "   authentication name"
            printsetvar "UNIMOUNT_${idx}_AUTH_PASS" "   authentication password"

            idx=`expr ${idx} + 1`
        done

        #------------------------------------------------------------------------------
        printend
        #------------------------------------------------------------------------------
    } > ${generate_conf}

    anykey
}

#==============================================================================
# main
#==============================================================================

#testroot=/soft/jedunimount
 testroot=''

module_name='mini_httpd_unimount'
configfile=${testroot}/etc/config.d/${module_name}
installfile=${testroot}/var/run/${module_name}.install
defaultfile=${testroot}/etc/default.d/${module_name}

# setting defaults
source_conf=${installfile}
generate_conf=${configfile}

goflag=0

case "$1"
in
    update)
        goflag=1
        ;;
    test)
        source_conf=${configfile}

        generate_conf=${testroot}/etc/config.d/${module_name}.test
        goflag=1
        ;;
    *)
        mecho
        mecho "Use one of the following options:"
        mecho
        mecho "  ${module_name}-update.sh [update] - the file ${module_name}.import will be read, the configuration will"
        mecho "                                    be checked and an updated mail configuration file will be written."
        mecho
        goflag=0
esac

if [ ${goflag} -eq 1 ]
then
    if [ -f ${source_conf} ]
    then
        # previous configuration file exists
        mecho -info "previous configuration found ..."
        . ${source_conf}

        pre_add_variables
        rename_variables
        modify_variables
        add_variables
        delete_variables

        create_config
    else
        mecho -error "no configuration ${source_conf} found - exiting."
        anykey
    fi
fi

#==============================================================================
# end
#==============================================================================
